@@ -1,22 +1,23 @@
 package Template::Liquid::Variable;
 { $Template::Liquid::Variable::VERSION = 'v1.0.0' }
 require Template::Liquid::Error;
-our @ISA = qw[Template::Liquid::Document];
+use base 'Template::Liquid::Document';
 
 sub new {
     my ($class, $args) = @_;
-    raise Template::Liquid::ContextError {
-                                       message => 'Missing template argument',
-                                       fatal   => 1
+    raise Template::Liquid::Error {type    => 'Context',
+                                   message => 'Missing template argument',
+                                   fatal   => 1
         }
         if !defined $args->{'template'}
         || !$args->{'template'}->isa('Template::Liquid');
-    raise Template::Liquid::ContextError {
-                                         message => 'Missing parent argument',
-                                         fatal   => 1
+    raise Template::Liquid::Error {type    => 'Context',
+                                   message => 'Missing parent argument',
+                                   fatal   => 1
         }
         if !defined $args->{'parent'};
-    raise Template::Liquid::SyntaxError {
+    raise Template::Liquid::Error {
+                   type    => 'Syntax',
                    message => 'Missing variable name in ' . $args->{'markup'},
                    fatal   => 1
         }
@@ -26,17 +27,23 @@ sub new {
 
 sub render {
     my ($s) = @_;
-    my $val = $s->{template}{context}->resolve($s->{'variable'});
-FILTER: for my $filter (@{$s->{'filters'}}) {
-        my ($name, $args) = @$filter;
-        map { $_ = $s->{template}{context}->resolve($_) || $_ } @$args;
-    PACKAGE: for my $package (@{$s->{template}{filters}}) {
-            if (my $call = $package->can($name)) {
-                $val = $call->($val, @$args);
-                next FILTER;
+    my $val = $s->{template}{context}->resolve($s->{variable});
+    {    # XXX - Duplicated in Template::Liquid::Assign::render
+        if (scalar @{$s->{filters}}) {
+            my %_filters = $s->{template}->filters;
+        FILTER: for my $filter (@{$s->{filters}}) {
+                my ($name, $args) = @$filter;
+                map { $_ = $s->{template}{context}->resolve($_) || $_ }
+                    @$args;
+                my $package = $_filters{$name};
+                my $call = $package ? $package->can($name) : ();
+                if ($call) {
+                    $val = $call->($val, @$args);
+                    next FILTER;
+                }
+                raise Template::Liquid::FilterNotFound $name;
             }
         }
-        raise Template::Liquid::FilterNotFound $name;
     }
     return join '', @$val      if ref $val eq 'ARRAY';
     return join '', keys %$val if ref $val eq 'HASH';
@@ -61,8 +68,8 @@ handling echo statements:
 Internally, a variable is the basic container for everything; lists, scalars,
 hashes, and even objects.
 
-L<Filters|Template::Liquid::Filter> are applied to Template::Liquid::Variable during the
-render stage.
+L<Filters|Template::Liquid::Filters::Standard> are applied to variables during
+the render stage.
 
 =head1 Author
 
